@@ -36,8 +36,7 @@
 #include <KLocalizedString>
 #include <QTemporaryFile>
 
-#include <KProcess>
-#include "pimsettingexportcore_debug.h"
+#include "pimdataexportcore_debug.h"
 
 #include <QFile>
 #include <QDir>
@@ -174,7 +173,7 @@ void ExportMailJob::slotWriteNextArchiveResource()
                             connect(this, &ExportMailJob::taskCanceled, resourceJob, &ExportResourceArchiveJob::slotTaskCanceled);
                             resourceJob->start();
                         } else {
-                            qCDebug(PIMSETTINGEXPORTERCORE_LOG) << "Url is empty for " << identifier;
+                            qCDebug(PIMDATAEXPORTERCORE_LOG) << "Url is empty for " << identifier;
                             QTimer::singleShot(0, this, &ExportMailJob::slotMailsJobTerminated);
                         }
                     } else {
@@ -213,7 +212,7 @@ void ExportMailJob::backupTransports()
         KConfig *config = mailtransportsConfig->copyTo(tmp.fileName());
 
         config->sync();
-        const bool fileAdded = archive()->addLocalFile(tmp.fileName(), Utils::transportsPath() + QLatin1String("mailtransports"));
+        const bool fileAdded = archive()->addLocalFile(tmp.fileName(), Utils::transportsPath() + QStringLiteral("mailtransports"));
         delete config;
         if (fileAdded) {
             Q_EMIT info(i18n("Transports backup done."));
@@ -257,7 +256,7 @@ void ExportMailJob::backupResources()
                         Q_EMIT error(errorStr);
                     }
                 } else {
-                    qCDebug(PIMSETTINGEXPORTERCORE_LOG) << " resource \"" << identifier << "\" will not store";
+                    qCDebug(PIMDATAEXPORTERCORE_LOG) << " resource \"" << identifier << "\" will not store";
                 }
             }
         }
@@ -270,7 +269,7 @@ void ExportMailJob::backupConfig()
 {
     setProgressDialogLabel(i18n("Backing up config..."));
 
-    QList<MailCommon::MailFilter *> lstFilter = MailCommon::FilterManager::instance()->filters();
+    QVector<MailCommon::MailFilter *> lstFilter = MailCommon::FilterManager::instance()->filters();
     if (!lstFilter.isEmpty()) {
         QTemporaryFile tmp;
         tmp.open();
@@ -278,7 +277,7 @@ void ExportMailJob::backupConfig()
         MailCommon::FilterImporterExporter exportFilters;
         exportFilters.exportFilters(lstFilter, url, true);
         tmp.close();
-        const bool fileAdded = archive()->addLocalFile(tmp.fileName(), Utils::configsPath() + QLatin1String("filters"));
+        const bool fileAdded = archive()->addLocalFile(tmp.fileName(), Utils::configsPath() + QStringLiteral("filters"));
         if (fileAdded) {
             Q_EMIT info(i18n("Filters backup done."));
         } else {
@@ -316,7 +315,6 @@ void ExportMailJob::backupConfig()
     backupConfigFile(QStringLiteral("texttospeechrc"));
     backupConfigFile(QStringLiteral("kleopatracertificateselectiondialogrc"));
 
-
     //Notify file config
     backupConfigFile(QStringLiteral("akonadi_mailfilter_agent.notifyrc"));
     backupConfigFile(QStringLiteral("akonadi_sendlater_agent.notifyrc"));
@@ -422,26 +420,26 @@ void ExportMailJob::backupConfig()
     storeDirectory(QStringLiteral("/messageviewerplugins/"));
     storeDirectory(QStringLiteral("/messageviewer/themes/"));
 
-    const QDir gravatarDirectory(QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QLatin1String("/gravatar/"));
+    const QDir gravatarDirectory(QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QStringLiteral("/gravatar/"));
     if (gravatarDirectory.exists()) {
         const QFileInfoList listFileInfo = gravatarDirectory.entryInfoList(QStringList() << QStringLiteral("*.png"), QDir::Files);
         const int listSize(listFileInfo.size());
         for (int i = 0; i < listSize; ++i) {
-            backupFile(listFileInfo.at(i).absoluteFilePath(), Utils::dataPath() + QLatin1String("gravatar/"), listFileInfo.at(i).fileName());
+            backupFile(listFileInfo.at(i).absoluteFilePath(), Utils::dataPath() + QStringLiteral("gravatar/"), listFileInfo.at(i).fileName());
         }
     }
 
-    const QDir autocorrectDirectory(QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QLatin1String("/autocorrect/"));
+    const QDir autocorrectDirectory(QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QStringLiteral("/autocorrect/"));
     if (autocorrectDirectory.exists()) {
         const QFileInfoList listFileInfo = autocorrectDirectory.entryInfoList(QStringList() << QStringLiteral("*.xml"), QDir::Files);
         const int listSize(listFileInfo.size());
         for (int i = 0; i < listSize; ++i) {
-            backupFile(listFileInfo.at(i).absoluteFilePath(), Utils::dataPath() + QLatin1String("autocorrect/"), listFileInfo.at(i).fileName());
+            backupFile(listFileInfo.at(i).absoluteFilePath(), Utils::dataPath() + QStringLiteral("autocorrect/"), listFileInfo.at(i).fileName());
         }
     }
-    const QString adblockFilePath = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QLatin1String("/kmail2/adblockrules_local");
+    const QString adblockFilePath = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QStringLiteral("/kmail2/adblockrules_local");
     if (QFileInfo::exists(adblockFilePath)) {
-        backupFile(adblockFilePath, Utils::dataPath() + QLatin1String("kmail2/"), QStringLiteral("adblockrules_local"));
+        backupFile(adblockFilePath, Utils::dataPath() + QStringLiteral("kmail2/"), QStringLiteral("adblockrules_local"));
     }
 
     const QString kmailStr(QStringLiteral("kmail2rc"));
@@ -509,6 +507,8 @@ void ExportMailJob::backupConfig()
                     if (!realPath.isEmpty()) {
                         storageGroup.writeEntry(QStringLiteral("%1%2").arg(storageModelSelectedPattern, realPath), oldValue);
                         storageGroup.deleteEntry(str);
+                    } else {
+                        storageGroup.deleteEntry(str);
                     }
                 }
             }
@@ -600,6 +600,22 @@ void ExportMailJob::backupConfig()
 
         //TODO add confirm address too
 
+        //Clean up kmail2rc
+        const QString tipOfDaysStr(QStringLiteral("TipOfDay"));
+        if (kmailConfig->hasGroup(tipOfDaysStr)) {
+            kmailConfig->deleteGroup(tipOfDaysStr);
+        }
+        const QString startupStr(QStringLiteral("Startup"));
+        if (kmailConfig->hasGroup(startupStr)) {
+            kmailConfig->deleteGroup(startupStr);
+        }
+
+        const QString search(QStringLiteral("Search"));
+        if (kmailConfig->hasGroup(search)) {
+            KConfigGroup searchGroup = kmailConfig->group(search);
+            searchGroup.deleteGroup();
+        }
+
         kmailConfig->sync();
         backupFile(tmp.fileName(), Utils::configsPath(), kmailStr);
         delete kmailConfig;
@@ -655,7 +671,7 @@ void ExportMailJob::backupIdentity()
         }
 
         identityConfig->sync();
-        const bool fileAdded = archive()->addLocalFile(tmp.fileName(), Utils::identitiesPath() + QLatin1String("emailidentities"));
+        const bool fileAdded = archive()->addLocalFile(tmp.fileName(), Utils::identitiesPath() + QStringLiteral("emailidentities"));
         delete identityConfig;
         if (fileAdded) {
             Q_EMIT info(i18n("Identity backup done."));
