@@ -25,7 +25,7 @@
 
 #include <QStringList>
 #include <QTimer>
-#include "pimsettingexportcore_debug.h"
+#include "pimdataexportcore_debug.h"
 
 SynchronizeResourceJob::SynchronizeResourceJob(QObject *parent)
     : QObject(parent)
@@ -49,7 +49,7 @@ void SynchronizeResourceJob::slotNextSync()
 {
     if (mIndex < mListResources.count()) {
         const Akonadi::AgentInstance resource = Akonadi::AgentManager::self()->instance(mListResources.at(mIndex));
-        qCDebug(PIMSETTINGEXPORTERCORE_LOG) << " resource.name" << resource.name();
+        qCDebug(PIMDATAEXPORTERCORE_LOG) << " resource.name" << resource.name();
         Akonadi::ResourceSynchronizationJob *job = new Akonadi::ResourceSynchronizationJob(resource);
         job->setTimeoutCountLimit(10);
         job->setCollectionTreeOnly(mOnlyCollection);
