@@ -17,13 +17,11 @@
    Boston, MA 02110-1301, USA.
 */
 
-#include "pimsettingexporterwindow.h"
-#include "pimsettingcommandlineoption.h"
+#include "pimdataexporterwindow.h"
+#include "pimdatacommandlineoption.h"
 
 #include <KLocalizedString>
 #include <KDBusService>
-#include <QCommandLineParser>
-#include <QCommandLineOption>
 #include <QApplication>
 #include <kdelibs4configmigrator.h>
 #include <KCrash>
@@ -33,26 +31,27 @@ int main(int argc, char *argv[])
     QCoreApplication::setAttribute(Qt::AA_EnableHighDpiScaling, true);
     QApplication app(argc, argv);
 
-    KLocalizedString::setApplicationDomain("pimsettingexporter");
+    KLocalizedString::setApplicationDomain("pimdataexporter");
 
     KCrash::initialize();
     app.setAttribute(Qt::AA_UseHighDpiPixmaps, true);
-    app.setDesktopFileName(QStringLiteral("org.kde.pimsettingexporter"));
-    Kdelibs4ConfigMigrator migrate(QStringLiteral("pimsettingexporter"));
+    app.setDesktopFileName(QStringLiteral("org.kde.pimdataexporter"));
+    Kdelibs4ConfigMigrator migrate(QStringLiteral("pimdataexporter"));
+    //old migration. Don't change it
     migrate.setConfigFiles(QStringList() << QStringLiteral("pimsettingexporterrc"));
     migrate.setUiFiles(QStringList() << QStringLiteral("pimsettingexporter.rc"));
     migrate.migrate();
     QApplication::setWindowIcon(QIcon::fromTheme(QStringLiteral("kontact")));
 
-    PimSettingCommandLineOption parser;
+    PimDataCommandLineOption parser;
     parser.createParser(app);
 
     KDBusService service(KDBusService::Unique);
 
-    PimSettingExporterWindow *backupMailWin = new PimSettingExporterWindow();
+    PimDataExporterWindow *backupMailWin = new PimDataExporterWindow();
     parser.setExportWindow(backupMailWin);
     QObject::connect(&service, &KDBusService::activateRequested,
-                     &parser, &PimSettingCommandLineOption::slotActivateRequested);
+                     &parser, &PimDataCommandLineOption::slotActivateRequested);
     backupMailWin->show();
     parser.handleCommandLine();
 
